version 11.1
clear all
capture log close
set more off
set mem 500m

use "final_import_dataset.dta", clear

/* Dependent variable */
gen share_intrafirm= REL_VAL/(REL_VAL+NON_VAL)

/* Creating industry variables */
gen i_capital=ln(total_capital/wages_employees)
for @ in any buildings materials machinery auto_machinery other_machinery: gen i_@=ln(@/wages_employees)
gen i_comp_machinery=ln(computer_machinery/wages_employees)
gen i_skill=ln((wages_employees-wages_production_workers)/(wages_employees))
gen i_RandD=ln(.000001+randd_intensity)
gen i_non_specific_mach=ln((auto_machinery+computer_machinery)/wages_employees)
gen i_non_specific_capital=ln((total_capital-other_machinery)/wages_employees)	/* buildings+auto_machinery+computer_machinery */
gen i_non_specific_capital2=ln((buildings+auto_machinery+computer_machinery)/wages_employees)

/* US Parent indicator */
gen US_parent_share=USparent/(USsub+USparent)

log using Antras_2003_exports.log, replace

*******************************************
*** TABLE 6: Regressions: Antras (2003) ***
*******************************************

/* Dropping cases where the US is the parent: US_parent_share_c < .35 only */
gen xx=0
for @ in any ISL ITA FIN LIE CHE SWE TWN BEL DNK BMU NOR KOR JPN ESP ISR: replace xx=1 if isocode=="@"
drop if xx!=1

* Col 1
xi: reg share_intrafirm i_RandD i_skill i_material i_capital i.isocode, cluster(io1997)
outreg2 using "Table6_tstats.xls", replace keep(i_RandD i_skill i_material i_capital i_material i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (tstat)			/* File with t-statsics (based on clustered SEs) */
xi: reg share_intrafirm i_RandD i_skill i_material i_capital i.isocode, beta
outreg2 using "Table6_betas.xls", replace keep(i_RandD i_skill i_material i_capital i_material i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) nocons aster dec(3) stats (beta)				/* File with beta coefficients */

* Col 2
xi: reg share_intrafirm i_RandD i_skill i_material i_buildings i_machinery i.isocode, cluster(io1997)
outreg2 using "Table6_tstats.xls", keep(i_RandD i_skill i_material i_capital i_material i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_material i_buildings i_machinery i.isocode, beta
outreg2 using "Table6_betas.xls", keep(i_RandD i_skill i_material i_capital i_material i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)	

* Col 3
xi: reg share_intrafirm i_RandD i_skill i_material i_buildings i_comp_machinery i_auto_machinery i_other_machinery i.isocode, cluster(io1997)
outreg2 using "Table6_tstats.xls", keep(i_RandD i_skill i_material i_capital i_material i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_material i_buildings i_comp_machinery i_auto_machinery i_other_machinery i.isocode, beta
outreg2 using "Table6_betas.xls", keep(i_RandD i_skill i_material i_capital i_material i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)	

* Col 4
xi: reg share_intrafirm i_RandD i_skill i_material i_buildings i_other_machinery i_non_specific_mach i.isocode, cluster(io1997)
outreg2 using "Table6_tstats.xls", keep(i_RandD i_skill i_material i_capital i_material i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_material i_buildings i_other_machinery i_non_specific_mach i.isocode, beta
outreg2 using "Table6_betas.xls", keep(i_RandD i_skill i_material i_capital i_material i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)	

* Col 5
xi: reg share_intrafirm i_RandD i_skill i_material i_other_machinery i_non_specific_capital i.isocode, cluster(io1997)
outreg2 using "Table6_tstats.xls", keep(i_RandD i_skill i_material i_capital i_material i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (tstat)
xi: reg share_intrafirm i_RandD i_skill i_material i_other_machinery i_non_specific_capital i.isocode, beta
outreg2 using "Table6_betas.xls", keep(i_RandD i_skill i_material i_capital i_material i_buildings i_machinery i_other_machinery i_non_specific_mach i_auto_machinery i_comp_machinery i_non_specific_mach i_non_specific_capital) append nocons aster dec(3) stats (beta)	

log close
